<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/page-404.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:50 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?xFFbujL6" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?ffQYemOL" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?Mh4G4rFw" id="font-awesome"></head>

<body class="layout4">

<div class="page-wrapper">

	<!-- Preloader -->
	<div class="preloader"></div>

	<!-- 404 Section -->
	<section class="">
		<div class="auto-container pt-120 pb-70">
			<div class="row">
				<div class="col-xl-12">
					<div class="error-page__inner">
						<div class="error-page__title-box">
							<img src="images/resource/404.jpg" alt="">
							<h3 class="error-page__sub-title">Page not found!</h3>
						</div>
						<p class="error-page__text">Sorry we can't find that page! The page you are looking <br> for
							was never existed.</p>
						<form class="error-page__form">
							<div class="error-page__form-input">
								<input type="search" placeholder="Search here">
								<button type="submit"><i class="lnr lnr-icon-magnifier"></i></button>
							</div>
						</form>
						<a href="index.html" class="theme-btn btn-style-one shop-now"><span class="btn-title">Back to Home</span></a>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!--End 404 Section -->

</div><!-- End Page Wrapper -->


<!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target" data-target="html"><span class="fa fa-angle-up"></span></div>

<script src="js/jquery.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/jquery.fancybox.js"></script>
<script src="js/jquery-ui.js"></script>
<script src="js/wow.js"></script>
<script src="js/appear.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/script.js"></script>



<script id="custom-js" src="js/code_editor_scripts.js?9Q4LGBN7"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/page-404.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:51 GMT --></html>